mysql.exceptions.server.Foreign_Data_String_Invalid_Cant_Create

Package mysql :: Package exceptions :: Module server :: Class Foreign_Data_String_Invalid_Cant_Create |
[hide private]
[frames] | no frames]

# Class Foreign_Data_String_Invalid_Cant_Create

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Foreign_Data_String_Invalid_Cant_Create

Can't create federated table. The data source connection string '%s' is not in the correct format

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`